@@ -242,6 +242,9 @@ FAILEDOPERATION_TASKNOTFOUND = 'FailedOperation.TaskNotFound'
 # 询价错误。
 FAILEDOPERATION_TRADECOMMON = 'FailedOperation.TradeCommon'
 
+# 账户余额不足
+FAILEDOPERATION_TRADEINSUFFICIENTBALANCE = 'FailedOperation.TradeInsufficientBalance'
+
 # 不可预知的错误。
 FAILEDOPERATION_UNEXPECTEDERROR = 'FailedOperation.UnexpectedError'
 
@@ -551,6 +554,9 @@ INVALIDPARAMETER_SUBNETNOTEXIST = 'InvalidParameter.SubnetNotExist'
 # 客户创建参数中，k8s 版本、运行时版本或 tke-eni-agent 版本不支持客户选择的操作系统中的CgroupV2。
 INVALIDPARAMETER_VERSIONNOTSUPPORTCGROUPV2 = 'InvalidParameter.VersionNotSupportCgroupV2'
 
+# 镜像未找到
+INVALIDPARAMETERVALUE_IMAGENOTFOUND = 'InvalidParameterValue.ImageNotFound'
+
 # 超出配额
 INVALIDPARAMETERVALUE_LIMITEXCEEDED = 'InvalidParameterValue.LimitExceeded'
 
